@@ -1,6 +1,6 @@
 /* The command handler for server-based "open" (after reception)
  *
- * Copyright 2008 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2018 by Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of librelp.
  *
@@ -134,10 +134,15 @@ BEGINcommand(S, Init)
 	pSess->pEngine->dbgprint("in open command handler\n");
 
 	if(pSess->bServerConnOpen) {
-		relpSessSendResponse(pSess, pFrame->txnr, (unsigned char*) "500 connection already open", 20);
+		if(pSess->pEngine->onErr) { // TODO: generalize!
+			pSess->pEngine->onErr(pSess->pUsr, "session", "received session open "
+				"request for already open session - aborting session",
+				RELP_RET_INVALID_FRAME);
+		}
+		unsigned char replymsg[] = "500 protocol error: connection already open";
+		relpSessSendResponse(pSess, pFrame->txnr, replymsg, sizeof(replymsg) - 1);
 		ABORT_FINALIZE(RELP_RET_SESSION_OPEN);
 	}
-
 	CHKRet(relpOffersConstructFromFrame(&pCltOffers, pFrame));
 	CHKRet(selectOffers(pSess, pCltOffers, &pSrvOffers));
 
